<?php
/*
* 2007-2010 PrestaShop 
*
* NOTICE OF LICENSE
*
* This source file is subject to the Open Software License (OSL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/osl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author Prestashop SA <contact@prestashop.com>
*  @copyright  2007-2010 Prestashop SA
*  @version  Release: $Revision: 1.4 $
*  @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

/*
* 2011 PrestaShop Gurkcity Edition 
*
* NOTICE OF LICENSE
*
* This source file is a modified version of the original file created by Prestashop SA
*
* This source file is subject to the Open Software License (OSL 3.0)
* It is available through the world-wide-web at this URL:
* http://opensource.org/licenses/osl-3.0.php
*
*  @author    Gurkcity <prestasho@gurkcity.de>
*  @copyright 2011 Gurkcity
*  @version   1.4 GC Edition
*  @license   http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
*/

if (!defined('_CAN_LOAD_FILES_'))
	exit;

class GCInvoice extends PaymentModule {
	
	/*
	*	Construct / Destruct
	*/
	
	public function __construct() {
		
		$this->name    = 'gcinvoice';
		$this->tab     = 'payments_gateways';
		$this->version = '1.4.3.0';
		$this->author  = 'Onlineshop-Module.de';
		
		parent::__construct();

		$this->displayName = $this->l('Invoice');
		$this->description = $this->l('Accept payments by invoice');
		
	}
	
	/*
	*	Install / Uninstall
	*/
	
	public function install() {
		
		if (
			   !parent::install() 
			OR !$this->registerHook('payment') 
			OR !$this->registerHook('paymentReturn')
		) {
			return false;
		}
		
		Configuration::updateValue('GC_INVOICE_MAX_VALUE', 100.0);
		
		if (!Configuration::get('GC_INVOICE_OS')) {
			
			$orderState = new OrderState();
			$orderState->name = array();
			foreach (Language::getLanguages() AS $language) {
				$orderState->name[$language['id_lang']] = 'Awaiting Payment: Invoice';
			}
			$orderState->send_email = false;
			$orderState->color = 'lightblue';
			$orderState->hidden = false;
			$orderState->delivery = true;
			$orderState->logable = true;
			$orderState->unremovable = true;
			$orderState->invoice = true;
			if ($orderState->add())
				copy(dirname(__FILE__).'/img/os_invoice.gif', dirname(__FILE__).'/../../img/os/'.(int)($orderState->id).'.gif');
			
			Configuration::updateValue('GC_INVOICE_OS', (int)($orderState->id));
			
		}
		
		return true;
		
	}

	public function uninstall() {
		
		if (
			   !Configuration::deleteByName('GC_INVOICE_MAX_VALUE') 
			OR !parent::uninstall()
		) {
			return false;
		}
		
		return true;
		
	}
	
	/*
	*	Hooks
	*/
	
	public function hookPayment($params) {
		
		if (!$this->active)
			return;
		
		global $cart;
		
		$total = $cart->getOrderTotal(true, Cart::BOTH);
		
		if($total > Configuration::get('GC_INVOICE_MAX_VALUE'))
			return;
		
		global $smarty;

		$smarty->assign(array(
			'this_path' => $this->_path,
			'this_path_ssl' => Tools::getShopDomainSsl(true, true).__PS_BASE_URI__.'modules/'.$this->name.'/'
		));
		
		return $this->display(__FILE__, 'payment.tpl');
		
	}

	public function hookPaymentReturn($params) {
		
		if (!$this->active)
			return ;

		global $smarty;
			
		$smarty->assign(array(
			'id_order' => $params['objOrder']->id
		));
		
		return $this->display(__FILE__, 'payment_return.tpl');
		
	}
	
	/*
	*	Custom Functions
	*/
	
	/*
	*	Admin integration
	*/
	
	public function getContent() {
		
		$html = '<h2>'.$this->displayName.'</h2>';

		$html .= $this->_postProcess();
		$html .= $this->_displayForm();

		return $html;
		
	}
	
	private function _postProcess() {
		
		if (isset($_POST['submitGCInvoice']) and Validate::isPrice($_POST['maxInvoiceValue']) and Configuration::updateValue('GC_INVOICE_MAX_VALUE', number_format($_POST['maxInvoiceValue'], 2, '.', ''))) {
			
			return '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('ok').'" /> '.$this->l('Settings updated').'</div>';
			
		}
		elseif(isset($_POST['submitGCInvoice'])) {
			
			return '<div class="conf error"><img src="../img/admin/error2.png" alt="'.$this->l('error').'" /> '.$this->l('Max invoice value').' '.$this->l('is no valid value').'</div>';
			
		}
		
		return '';
		
	}
	
	private function _displayForm() {
		
		return '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
			<fieldset>
			<legend>'.$this->l('Invoice Settings').'</legend>
				
				<label>'.$this->l('Max invoice value').':</label>
				
				<div class="margin-form">
					<input type="text" name="maxInvoiceValue" value="'.htmlentities(Configuration::get('GC_INVOICE_MAX_VALUE'), ENT_COMPAT, 'UTF-8').'" /> '.$this->l('Specify the invoice max value for orders').'
				</div>
				<br />
				
				<p class="center"><input class="button" name="submitGCInvoice" value="'.$this->l('Update settings').'" type="submit" /></p>
				
			</fieldset>
		</form>';
		
	}
	
}
